#version 330 core

// Interpolated values from the vertex shaders
//in vec3 fragmentColor;

in vec2 fragmentUV;
in vec3 normal_cs;
in vec3 lightdirection_cs[5];
in vec3 position_ws;
in vec3 eyedirection_cs;

out vec4 fragColor;

uniform sampler2D colorTexture;
uniform mat4 modelMatrix;
uniform mat4 viewMatrix;
uniform vec3 lightposition_ws[5];

 
void main(void){
//	const vec3 lightposition_ws[5] = vec3[5](vec3(0.0, 9.0, -8.0), vec3(0.0, 9.0, -32.0), vec3(0.0, 9.0, -56.0), vec3(0.0, 9.0, -80.0), vec3(0.0, 9.0, -104.0));


	vec4 textureColor = texture2D(colorTexture, fragmentUV);
	vec4 materialColor = textureColor; //vec4(textureColor, 1.0);
	vec4 ambient = vec4(0.1, 0.1, 0.1, 1) * materialColor;
	vec4 specular = vec4(0.3, 0.3, 0.3, 1);
	vec4 lightColor = vec4(1.0, 1.0, 1.0, 0.0);
	float lightPower = 40.0f;
	mat4 mv = viewMatrix * modelMatrix;

	fragColor = ambient;

	for (int u = 0; u < lightposition_ws.length(); ++u) {
		// Distance to the light
		float distance = length(lightposition_ws[u] - position_ws);

		// lightning
		vec3 n = normalize(normal_cs);
		vec3 l = normalize(lightdirection_cs[u]);
		float cosTheta = clamp(dot( n,l ), 0, 1);
		
		// speculars
		vec3 e = normalize(eyedirection_cs);
		vec3 r = reflect(-l,n);
		float cosAlpha = clamp(dot(e, r), 0, 1);

		fragColor += materialColor * lightColor * lightPower * cosTheta / (distance * distance) + // used to be (distance * distance) but I didn't like it for testing purposes
					specular * lightColor * lightPower * pow(cosAlpha, 10) / (distance * distance); // used to be (distance * distance) but I didn't like it for testing purposes
	}			
}